==> sqlalchemy_0.7.2.orig.tar.gz: SQLAlchemy-0.7.2/lib/sqlalchemy/util/__init__.py <==
# util/__init__.py
# Copyright (C) 2005-2011 the SQLAlchemy authors and contributors <see AUTHORS file>
#
# This module is part of SQLAlchemy and is released under
# the MIT License: http://www.opensource.org/licenses/mit-license.php

from compat import callable, cmp, reduce, defaultdict, py25_dict, \
    threading, py3k, jython, pypy, win32, set_types, buffer, pickle, \
    update_wrapper, partial, md5_hex, decode_slice, dottedgetter,\
    parse_qsl

from _collections import NamedTuple, ImmutableContainer, immutabledict, \
    Properties, OrderedProperties, ImmutableProperties, OrderedDict, \
    OrderedSet, IdentitySet, OrderedIdentitySet, column_set, \
    column_dict, ordered_column_set, populate_column_dict, unique_list, \
    UniqueAppender, PopulateDict, EMPTY_SET, to_list, to_set, \
    to_column_set, update_copy, flatten_iterator, WeakIdentityMapping, \
    LRUCache, ScopedRegistry, ThreadLocalRegistry

from langhelpers import iterate_attributes, class_hierarchy, \
    portable_instancemethod, unbound_method_to_callable, \
    getargspec_init, format_argspec_init, format_argspec_plus, \
    get_func_kwargs, get_cls_kwargs, decorator, as_interface, \
    memoized_property, memoized_instancemethod, \
    reset_memoized, group_expirable_memoized_property, importlater, \
    monkeypatch_proxied_specials, asbool, bool_or_str, coerce_kw_type,\
    duck_type_collection, assert_arg_type, symbol, dictlike_iteritems,\
    classproperty, set_creation_order, warn_exception, warn, NoneType,\
    constructor_copy, methods_equivalent, chop_traceback, asint,\
    generic_repr

from deprecations import warn_deprecated, warn_pending_deprecation, \
    deprecated, pending_deprecation

==> sqlalchemy_0.7.9.orig.tar.gz: SQLAlchemy-0.7.9/lib/sqlalchemy/util/__init__.py <==
# util/__init__.py
# Copyright (C) 2005-2012 the SQLAlchemy authors and contributors <see AUTHORS file>
#
# This module is part of SQLAlchemy and is released under
# the MIT License: http://www.opensource.org/licenses/mit-license.php

from compat import callable, cmp, reduce, defaultdict, py25_dict, \
    threading, py3k_warning, jython, pypy, cpython, win32, set_types, buffer, \
    pickle, update_wrapper, partial, md5_hex, decode_slice, dottedgetter,\
    parse_qsl, any, contextmanager, next

from _collections import NamedTuple, ImmutableContainer, immutabledict, \
    Properties, OrderedProperties, ImmutableProperties, OrderedDict, \
    OrderedSet, IdentitySet, OrderedIdentitySet, column_set, \
    column_dict, ordered_column_set, populate_column_dict, unique_list, \
    UniqueAppender, PopulateDict, EMPTY_SET, to_list, to_set, \
    to_column_set, update_copy, flatten_iterator, WeakIdentityMapping, \
    LRUCache, ScopedRegistry, ThreadLocalRegistry

from langhelpers import iterate_attributes, class_hierarchy, \
    portable_instancemethod, unbound_method_to_callable, \
    getargspec_init, format_argspec_init, format_argspec_plus, \
    get_func_kwargs, get_cls_kwargs, decorator, as_interface, \
    memoized_property, memoized_instancemethod, \
    reset_memoized, group_expirable_memoized_property, importlater, \
    monkeypatch_proxied_specials, asbool, bool_or_str, coerce_kw_type,\
    duck_type_collection, assert_arg_type, symbol, dictlike_iteritems,\
    classproperty, set_creation_order, warn_exception, warn, NoneType,\
    constructor_copy, methods_equivalent, chop_traceback, asint,\
    generic_repr, counter

from deprecations import warn_deprecated, warn_pending_deprecation, \
    deprecated, pending_deprecation
